@@ -130,7 +130,9 @@ f <- c(
 )
 
 ## ----error = TRUE-------------------------------------------------------------
+try({
 clean_metadata(project_files = f)
+})
 
 ## -----------------------------------------------------------------------------
 clean_metadata(project_files = f, file_type = "mp4")
